# Vigilant
# WORK IN PROGRESS

**Vigilant**  is a set of libraries made to simplify writing and running robust functional system tests  
using Selenium WebDriver. 

Works perfectly well with both **unittest** and **pytest** frameworks.